# m_stats
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/m_stats.svg) ![PyPI - License](https://img.shields.io/pypi/l/m_stats.svg)  ![PyPI](https://img.shields.io/pypi/v/m_stats.svg) ![GitHub last commit](https://img.shields.io/github/last-commit/mvelezg99/m_stats.svg)
***
A statistics and probability library for Python; which includes functions to make operations of:
* Probability distributions
* Confidence intervals estimation
* Hypothesis testing
* ANOVA (Analysis of variance)
* Simple linear regression
* Multiple regression
* Time series

And also includes functions to:
* Graph distributions
* Graph hypothesis tests
* Graph linear regressions
***

To use and explore the library, you can install it with PyPi.
```
$ pip install m_stats
```
And then import it into your files.
```python
import m_stats as ms
```
And to use its functionalities, you should access to them in this way:
```python
ms.linregr.regression(x, y)
```
***

